@@ -1,6 +1,7 @@
 package Signals::XSIG;
 
-## no critic (RequireLocalizedPunctuationVars, ProhibitAutomaticExport)
+## no critic (Variables::RequireLocalizedPunctuationVars)
+## no critic (Modules::ProhibitAutomaticExportation)
 
 use Signals::XSIG::Default;
 use Carp;
@@ -18,7 +19,7 @@ our @EXPORT_OK = qw(untied %DEFAULT_BEHAVIOR);
 our %DEFAULT_BEHAVIOR;
 *DEFAULT_BEHAVIOR = \%Signals::XSIG::Default::DEFAULT_BEHAVIOR;
 
-our $VERSION = '0.15_01';
+our $VERSION = '0.15_02';
 our (%XSIG, %_XSIG, %SIGTABLE, $_REFRESH, $_DISABLE_WARNINGS);
 our $_INITIALIZED = 0;
 our $SIGTIE = bless {}, 'Signals::XSIG::TieSIG';
@@ -29,7 +30,7 @@ our $XDEBUG = 0;  # to be removed when we get a handle on t/02 failures
 my %TIEDSCALARS = (); # map signal names to S::X::TiedScalar objs
 my %alias = ();
 
-BEGIN {
+BEGIN {                 ## no critic(StringyEval)
     # how to detect global destruction. Idea from Devel::GlobalDestruction 0.13
     if (defined ${^GLOBAL_PHASE}) {
         eval 'sub __inGD() {${^GLOBAL_PHASE} eq "DESTRUCT" && __END()}; 1';
@@ -100,8 +101,9 @@ sub __shadow__die__handler  {          ## no critic (Unpacking)
 END { &__END; }
 
 sub __END {
-    no warnings 'redefine';
+    no warnings 'redefine';  ## no critic (NoWarnings)
     *__inGD = sub () { 1 };
+    return;
 }
 
 sub __shadow_signal_handler {
@@ -288,7 +290,7 @@ sub Signals::XSIG::TieSIG::DELETE {
 sub Signals::XSIG::TieSIG::CLEAR {
     my ($self) = @_;
     $XDEBUG && push @{$self->{DEBUG_LOG}},[CLEAR=>[],time-$^T,[caller]];
-    $_XSIG{$_}[0] = undef for keys %XSIG;
+    $_XSIG{$_}[0] = undef for keys %_XSIG;
     return;
 }
 
@@ -312,7 +314,7 @@ sub Signals::XSIG::TieSIG::NEXTKEY {
     return each %_XSIG;
 }
 
-sub Signals::XSIG::TieSIG::UNTIE {
+sub Signals::XSIG::TieSIG::UNTIE { ## no critic(Unpacking)
     $XDEBUG && !__inGD()
             && push @{$_[0]->{DEBUG_LOG}},[UNTIE=>[$_[1]],time-$^T,[caller]];
     return;
@@ -640,7 +642,7 @@ Signals::XSIG - install multiple signal handlers through %XSIG
 
 =head1 VERSION
 
-Version 0.15_01
+Version 0.15_02
 
 =head1 SYNOPSIS
 
